

async function seedDatabase() {

    try {
      db = connect('mongodb://localhost/minecraftdb');
        // Hilfsfunktion zum Generieren von ObjectIds
        const generateIds = (count) => Array.from({ length: count }, () => new ObjectId());

        // IDs generieren
        const mobIds = generateIds(20);
        const itemIds = generateIds(20);
        const biomeIds = generateIds(20);
        const structureIds = generateIds(20);

        //  Beispiel-Daten für Items
        const items = [
            "Wooden Sword", "Iron Sword", "Diamond Sword", "Bow", "Golden Apple",
            "Shield", "TNT", "Ender Pearl", "Potion of Healing", "Emerald",
            "Bone", "Rotten Flesh", "Arrow", "Blaze Rod", "Nether Star",
            "Totem of Undying", "Dragon Egg", "Spider Eye", "Lapis Lazuli", "Obsidian"
        ].map((name, i) => ({
            _id: itemIds[i],
            name,
            rarity: ["Common", "Uncommon", "Rare", "Legendary"][Math.floor(Math.random() * 4)],
            used_for: ["Combat", "Crafting", "Exploration", "Magic"][Math.floor(Math.random() * 4)],
            value: Math.floor(Math.random() * 100),
            durability: Math.random() > 0.5 ? Math.floor(Math.random() * 500) + 1 : null,
            dropped_by_mobs: [mobIds[i % 20]]
        }));
        await db.items.insertMany(items);

        //  Beispiel-Daten für Strukturen
        const structures = [
            "Nether Fortress", "Desert Temple", "Village", "Mineshaft", "Woodland Mansion",
            "Stronghold", "Pillager Outpost", "End City", "Ocean Monument", "Ruined Portal",
            "Shipwreck", "Bastion Remnant", "Jungle Temple", "Igloo", "Ancient City",
            "Swamp Hut", "Ice Spikes", "Mushroom Island", "Cave System", "Witch Hut"
        ].map((name, i) => ({
            _id: structureIds[i],
            name,
            length: Math.floor(Math.random() * 100) + 10,
            width: Math.floor(Math.random() * 50) + 10,
            height: Math.floor(Math.random() * 30) + 5,
            loot: [itemIds[i % 20], itemIds[(i + 1) % 20]],
            dangerousness: Math.floor(Math.random() * 10) + 1
        }));
        await db.structures.insertMany(structures);

        //  Beispiel-Daten für Biome
        const biomes = [
            "Plains", "Desert", "Jungle", "Snowy Tundra", "Swamp",
            "Badlands", "Savanna", "Dark Forest", "Taiga", "Birch Forest",
            "Mountains", "Deep Ocean", "Coral Reef", "Mushroom Fields", "The End",
            "The Nether", "Cherry Grove", "Frozen River", "Dripstone Caves", "Lush Caves"
        ].map((name, i) => ({
            _id: biomeIds[i],
            name,
            temperature: Math.floor(Math.random() * 50) - 10,
            precipitation: ["None", "Low", "Moderate", "High"][Math.floor(Math.random() * 4)],
            mobs: [mobIds[i % 20], mobIds[(i + 1) % 20]],
            structures: [structureIds[i % 20], structureIds[(i + 1) % 20]]
        }));
        await db.biomes.insertMany(biomes);

        //  Beispiel-Daten für Mobs
        const mobs = [
            "Zombie", "Skeleton", "Creeper", "Spider", "Enderman",
            "Wither Skeleton", "Blaze", "Ghast", "Slime", "Magma Cube",
            "Witch", "Pillager", "Ravager", "Iron Golem", "Guardian",
            "Elder Guardian", "Shulker", "Ender Dragon", "Warden", "Evoker"
        ].map((name, i) => ({
            _id: mobIds[i],
            name,
            category: ["Undead", "Beast", "Elemental", "Magical", "Humanoid"][Math.floor(Math.random() * 5)],
            health: Math.floor(Math.random() * 50) + 10,
            damage: Math.floor(Math.random() * 10),
            loot: [itemIds[i % 20], itemIds[(i + 1) % 20]],
            biomes: [biomeIds[i % 20], biomeIds[(i + 1) % 20]],
            special_ability: ["Burns in daylight", "Shoots arrows", "Explodes on approach", "Teleports", "Poison attack",
                              "Spawns minions", "Can fly", "Regenerates health", "Steals items", "Turns invisible"][i % 10]
        }));
        await db.mobs.insertMany(mobs);

        console.log("20 Beispiel-Daten für jede Collection erfolgreich eingefügt!");

    } catch (error) {
        console.error("Fehler beim Einfügen der Daten:", error);
    } finally {
        console.log("🔌 Verbindung zu MongoDB geschlossen.");
    }
}

// Skript ausführen
seedDatabase();
