<?php
require 'database.php';
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

$db = new Database();
$mobs = $db->getMobsCollection();
$itemsCollection = $db->getItemsCollection();
$biomes = $db->getBiomesCollection();

function resolveReference($collection, $objectIds) {
    $names = [];
    
    if (!is_array($objectIds)) {
        return $names; // Falls keine gültige Liste, direkt zurückgeben
    }

    foreach ($objectIds as $id) {
        // Sicherstellen, dass es eine gültige ObjectId ist
        if ($id instanceof MongoDB\BSON\ObjectId) {
            $item = $collection->findOne(['_id' => $id]);
            if ($item && isset($item['name'])) {
                $names[] = $item['name']; // Wir gehen davon aus, dass "name" existiert
            }
        }
    }
    return $names;
}

// GET (Daten abrufen, Mobs)
if ($_SERVER['REQUEST_METHOD'] === 'GET') {
	// Extrahiere den Pfad der Anfrage (URL)
	$requestUri = $_SERVER['REQUEST_URI'];

	// /loot
    if (strpos($requestUri, '/loot') !== false) {
		$loot = $itemsCollection->find()->toArray();
        echo json_encode($loot);
    }
	// /biomes
	elseif (strpos($requestUri, '/biomes') !== false) {
        // Hier kannst du die Biome-Daten zurückgeben
        echo json_encode($biomes);
    } else {
		$items = $mobs->find()->toArray();
		// Durchlaufe die Mobs und ersetze Loot und Biomes mit den Namen
		foreach ($items as &$mob) {
			if (isset($mob['loot']) && $mob['loot'] instanceof MongoDB\Model\BSONArray) {
				$mob['loot'] = resolveReference($itemsCollection, (array) $mob['loot']); // Konvertiere BSONArray in normales Array
			}
			if (isset($mob['biomes']) && $mob['biomes'] instanceof MongoDB\Model\BSONArray) {
				$mob['biomes'] = resolveReference($biomes, (array) $mob['biomes']); // Konvertiere BSONArray in normales Array
			}
		}
		echo json_encode($items);
	}
}

// POST (Daten hinzufügen)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $data = json_decode(file_get_contents("php://input"), true);
    if ($data) {
        $insertResult = $mobs->insertOne($data);
        echo json_encode(["message" => "Mob hinzugefügt", "id" => $insertResult->getInsertedId()]);
    }
}

// PUT (Daten aktualisieren)
if ($_SERVER['REQUEST_METHOD'] === 'PUT') {
   parse_str($_SERVER['QUERY_STRING'], $query);
    if (isset($query['id'])) {
        $data = json_decode(file_get_contents("php://input"), true);
        $mobs->updateOne(["_id" => new MongoDB\BSON\ObjectId($query['id'])], ['$set' => $data]);
        echo json_encode(["message" => "Mob aktualisiert"]);
    }
}

// DELETE (Daten löschen)
if ($_SERVER['REQUEST_METHOD'] === 'DELETE') {
    parse_str($_SERVER['QUERY_STRING'], $query);
    if (isset($query['id'])) {
        $mobs->deleteOne(["_id" => new MongoDB\BSON\ObjectId($query['id'])]);
        echo json_encode(["message" => "Mob gelöscht"]);
    }
}
?>
