async function seedDatabase() {
    const generateObjectIds = (count) => Array.from({ length: count }, () => new ObjectId());

    const items = Array.from({ length: 1000 }, (_, i) => ({
        _id: new ObjectId(),
        name: `Item ${i + 1}`,
        rarity: ["Common", "Uncommon", "Rare", "Legendary"][Math.floor(Math.random() * 4)],
        used_for: ["Combat", "Crafting", "Exploration", "Magic"][Math.floor(Math.random() * 4)],
        value: Math.floor(Math.random() * 100),
        durability: Math.random() > 0.5 ? Math.floor(Math.random() * 500) + 1 : null,
        dropped_by_mobs: generateObjectIds(2)
    }));
    await db.items.insertMany(items);
    
    const structures = Array.from({ length: 1000 }, (_, i) => ({
        _id: new ObjectId(),
        name: `Structure ${i + 1}`,
        length: Math.floor(Math.random() * 100) + 10,
        width: Math.floor(Math.random() * 50) + 10,
        height: Math.floor(Math.random() * 30) + 5,
        loot: generateObjectIds(2),
        dangerousness: Math.floor(Math.random() * 10) + 1
    }));
    await db.structures.insertMany(structures);
    
    const biomes = Array.from({ length: 1000 }, (_, i) => ({
        _id: new ObjectId(),
        name: `Biome ${i + 1}`,
        temperature: Math.floor(Math.random() * 50) - 10,
        precipitation: ["None", "Low", "Moderate", "High"][Math.floor(Math.random() * 4)],
        mobs: generateObjectIds(2),
        structures: generateObjectIds(2)
    }));
    await db.biomes.insertMany(biomes);
    
    const mobs = Array.from({ length: 1000 }, (_, i) => ({
        _id: new ObjectId(),
        name: `Mob ${i + 1}`,
        category: ["Undead", "Beast", "Elemental", "Magical", "Humanoid"][Math.floor(Math.random() * 5)],
        health: Math.floor(Math.random() * 50) + 10,
        damage: Math.floor(Math.random() * 10),
        loot: generateObjectIds(2),
        biomes: generateObjectIds(2),
        special_ability: ["Burns in daylight", "Shoots arrows", "Explodes on approach", "Teleports", "Poison attack",
                          "Spawns minions", "Can fly", "Regenerates health", "Steals items", "Turns invisible"][i % 10]
    }));
    await db.mobs.insertMany(mobs);
    
}
seedDatabase();
