const API_URL = "http://localhost/minecraft_mobs_m165/api.php";

// CREATE
document.addEventListener("DOMContentLoaded", () => {
    loadMobs();

    document.getElementById("mobForm").addEventListener("submit", async (event) => {
        event.preventDefault();
        const mobId = document.getElementById("mobId").value;
        const mobData = {
            name: document.getElementById("name").value,
            category: document.getElementById("category").value,
            health: parseInt(document.getElementById("health").value),
            damage: parseInt(document.getElementById("damage").value),
            special_ability: document.getElementById("special_ability").value
        };

        if (mobId) {
            await fetch(`api.php?id=${mobId}`, { method: "PUT", body: JSON.stringify(mobData) });
        } else {
            await fetch("api.php", { method: "POST", body: JSON.stringify(mobData) });
        }
        
        document.getElementById("mobForm").reset();
        loadMobs();
    });
});

//  READ
async function loadMobs() {
    const response = await fetch(API_URL + '/mobs');
    const mobs = await response.json();

    const tableBody = document.querySelector("#mobTable tbody");
    tableBody.innerHTML = '';  // Tabelle leeren

    mobs.forEach(mob => {
        const row = document.createElement('tr');
        
        const nameCell = document.createElement('td');
        nameCell.textContent = mob.name;
        row.appendChild(nameCell);

        const categoryCell = document.createElement('td');
        categoryCell.textContent = mob.category;
        row.appendChild(categoryCell);

        const healthCell = document.createElement('td');
        healthCell.textContent = mob.health;
        row.appendChild(healthCell);

        const damageCell = document.createElement('td');
        damageCell.textContent = mob.damage;
        row.appendChild(damageCell);

        const specialAbilityCell = document.createElement('td');
        specialAbilityCell.textContent = mob.special_ability || 'Keine';
        row.appendChild(specialAbilityCell);
		
		 // Loot anzeigen
        const lootCell = document.createElement('td');
        lootCell.textContent = mob.loot ? mob.loot.join(', ') : 'Kein Loot';  // Hier gehen wir davon aus, dass loot ein Array von Namen ist
        row.appendChild(lootCell);

        // Biomes anzeigen
        const biomesCell = document.createElement('td');
        biomesCell.textContent = mob.biomes ? mob.biomes.join(', ') : 'Keine Biome';  // Hier gehen wir davon aus, dass biomes ein Array von Namen ist
        row.appendChild(biomesCell);

		// Edit Button
		const deleteCell = document.createElement('td');
		const deleteButton = document.createElement('button');
		deleteButton.textContent = 'Löschen';
		deleteButton.addEventListener('click', () => {
			deleteMob(mob._id.$oid);
		});
		deleteCell.appendChild(deleteButton);
		row.append(deleteCell);
		
		// Edit Button
		const editCell = document.createElement('td');
		const editButton = document.createElement('button');
		editButton.textContent = 'Bearbeiten';
		editButton.addEventListener('click', () => {
			editMob(mob._id.$oid, mob.name, mob.category, mob.health, mob.damage, mob.special_ability);
		});
		editCell.appendChild(editButton);
		row.append(editCell);

        tableBody.appendChild(row);
    });
}

async function loadLoot() {
    const response = await fetch(API_URL + '/loot');
    const lootItems = await response.json();

    const selectBody = document.getElementById("lootSelect");
    selectBody.innerHTML = ''; // Leere das Dropdown-Menü, bevor du neue Optionen hinzufügst

    lootItems.forEach(loot => {
        const optionEle = document.createElement('option');
        optionEle.innerHTML = loot.name; // Wir gehen davon aus, dass loot direkt der Name ist
        optionEle.value = loot._id; // Das gleiche gilt hier, wir setzen den Wert auf den Namen des Loots
       
        selectBody.appendChild(optionEle); // Füge das option-Element hinzu
    });
}

// EDIT
function editMob(id, name, category, health, damage, ability) {
    document.getElementById("mobId").value = id;
    document.getElementById("name").value = name;
    document.getElementById("category").value = category;
    document.getElementById("health").value = health;
    document.getElementById("damage").value = damage;
    document.getElementById("special_ability").value = ability;
}

// DELETE
async function deleteMob(id) {
    if (confirm("Willst du diesen Mob wirklich löschen?")) {
        await fetch(`api.php?id=${id}`, { method: "DELETE" });
        loadMobs();
    }
}

loadMobs(); // Daten beim Laden abrufen
loadLoot();